@@ -283,7 +283,7 @@ class QueryWrapper(Neo4jConnect):
     def _query(self, q):
         qr = self.commit_list([q])
         if not qr:
-            raise Exception('Query failed.')
+            raise Exception(f'Query failed: {q}')
         else:
             r = dict_cursor(qr)
             if not r:
@@ -329,8 +329,11 @@ class QueryWrapper(Neo4jConnect):
                     continue
                 for imv in image_matches:
                     if imv['template_anatomy']['label'] == template:
-                        r = requests.get(imv['image_folder'] + '/volume.' + image_type)
-                        ### Slightly dodgy warning - could mask network errors
+                        try:
+                            r = requests.get(imv['image_folder'] + '/volume.' + image_type)
+                        except requests.exceptions.RequestException as e:
+                            print(f"\033[33mWarning:\033[0m No '{image_type}' file found for '{label}'. Error: {e}")
+                            continue
                         if not r.ok:
                             print("33mWarning:\033[0m No '%s' file found for '%s'." % (image_type, label))
                             continue
@@ -347,14 +350,16 @@ class QueryWrapper(Neo4jConnect):
 
         :return: list of VFB IDs."""
         query = "MATCH (i:Individual) " \
-                "WHERE 'Site' in labels(i) OR 'API' in labels(i)" \
-                "return i.short_form"
-        dbs = [d['i.short_form'] for d in self._query(query)]
+                "WHERE i:Site OR i:API " \
+                "return i.short_form as id"
+        results = self._query(query)
+        dbs = [d['id'] for d in results]
         if include_symbols:
             query = "MATCH (i:Individual) " \
-                    "WHERE 'Site' in labels(i) OR 'API' in labels(i) AND exists(i.symbol) and not i.symbol[0] = '' " \
-                    "RETURN i.symbol"
-            dbs.extend([d['i.symbol'] for d in self._query(query) if d['i.symbol']])
+                    "WHERE i:Site OR i:API AND exists(i.symbol) and not i.symbol[0] = '' " \
+                    "RETURN i.symbol[0] as symbol"
+            results = self._query(query)
+            dbs.extend([d['symbol'] for d in results if d['symbol']])
         return dbs
 
     def get_datasets(self, summary=True, return_dataframe=True):
@@ -371,7 +376,6 @@ class QueryWrapper(Neo4jConnect):
                 `return_dataframe` is `True` and `summary` is `True`.
         :rtype: list of dicts or pandas.DataFrame
         """
-
         dc = self._query("MATCH (ds:DataSet) "
                         "RETURN ds.short_form AS sf")
         short_forms = [d['sf'] for d in dc]
@@ -430,7 +434,7 @@ class QueryWrapper(Neo4jConnect):
         mapping = self.vfb_id_2_xrefs(vfb_id, db=db, reverse_return=True)
         return [int(k) for k, v in mapping.items()]
 
-    def xref_2_vfb_id(self, acc=None, db='', id_type='', reverse_return=False):
+    def xref_2_vfb_id(self, acc=None, db='', id_type='', reverse_return=False, verbose=False):
         """Map a list external DB IDs to VFB IDs
 
           :param acc: An iterable (e.g. a list) of external IDs (e.g. neuprint bodyIDs).
@@ -442,6 +446,8 @@ class QueryWrapper(Neo4jConnect):
               Return if `reverse_return` is `True`:
                 dict { VFB_id : [{ db: <db> : acc : <acc> }
           """
+        if isinstance(acc, str):
+            acc = [acc]
         match = "MATCH (s:Individual)<-[r:database_cross_reference]-(i:Entity) WHERE"
         conditions = []
         if not (acc is None):
@@ -458,7 +464,9 @@ class QueryWrapper(Neo4jConnect):
             ret = "RETURN i.short_form as key, " \
                   "collect({ db: s.short_form, acc: r.accession[0]}) as mapping"
         q = ' '.join([match, condition_clauses, ret])
+        print(q) if verbose else None
         dc = self._query(q)
+        print(dc) if verbose else None
         return {d['key']: d['mapping'] for d in dc}
 
     @batch_query
@@ -640,6 +648,25 @@ class QueryWrapper(Neo4jConnect):
                 dc.append(_populate_instance_summary_tab(r))
         print(f"Got {len(dc)} results.") if verbose else None
         return dc
+    
+    def _query_2_summary(self, TermInfo, typ, verbose=False):
+        # type_2_summary = {
+        #     'Get JSON for Individual': '_populate_instance_summary_tab',
+        #     'Get JSON for Class': '_populate_anatomical_entity_summary',
+        # }
+        dc = []
+        for r in TermInfo:
+            if 'Class' in typ:
+                print(f"Getting Class: {r['short_form']}") if verbose else None
+                dc.append(_populate_anatomical_entity_summary(r))
+            elif typ == 'Get JSON for DataSet':
+                print(f"Getting DataSet: {r['short_form']}") if verbose else None
+                dc.append(_populate_dataset_summary_tab(r))
+            else:
+                print(f"Getting Individual: {r['short_form']}") if verbose else None
+                dc.append(_populate_instance_summary_tab(r))
+        print(f"Got {len(dc)} results.") if verbose else None
+        return dc
 
     def _serialize_solr_output(self, results):
         """
