@@ -1,5 +1,4 @@
 import requests
-import warnings
 import re
 import json
 from ..default_servers import get_default_servers
@@ -31,7 +30,8 @@ class OWLeryConnect:
                  endpoint=get_default_servers()['owlery_endpoint'],
                  lookup=None,
                  obo_curies=('FBbt', 'RO', 'BFO'),
-                 curies=None):
+                 curies=None,
+                 obo_format=True):
         self.owlery_endpoint = endpoint
         if not (lookup):
             self.lookup = {}
@@ -51,7 +51,7 @@ class OWLeryConnect:
         self.curies.update(c)
 
     def query(self, query_type, return_type,
-              query, query_by_label=False, direct=False, verbose=False):
+              query, query_by_label=True, direct=False, verbose=False):
         """
         A wrapper for querying Owlery Endpoints.  See
         https://owlery.phenoscape.org/api/ for doc
@@ -69,68 +69,92 @@ class OWLeryConnect:
         owl_endpoint = self.owlery_endpoint + query_type +"?"
         if query_by_label:
             query = self.labels_2_ids(query)
-        print("Running query: " + query)
+        if verbose:
+            print("Running query: " + query) 
         payload = {'object': query, 'prefixes': json.dumps(self.curies),
                    'direct': direct}
         # print(payload)
         r = requests.get(url=owl_endpoint, params=payload)
-        print("Query URL: " + r.url)
+        if verbose:
+            print("Query URL: " + r.url)
         if r.status_code == 200:
-            print("Query results: " + str(len(r.json()[return_type])))
+            if verbose:
+                print("\033[32mQuery results:\033[0m " + str(len(r.json()[return_type])))
             return r.json()[return_type]
         else:
-            warnings.warn(str(r.content))
+            print("\033[31mConnection Error:\033[0m " + str(r.content))
             return False
 
-    def get_subclasses(self, query, query_by_label=False, direct=False, return_short_forms=False):
+    def get_subclasses(self, query, query_by_label=True, direct=False, return_short_forms=True, verbose=False):
         """Generate list of IDs of all subclasses of class_expression.
 
                 :param class_expression: A valid OWL class expression, e.g. the name of a class.
                 :param query_by_label: Optional.  If `False``, class_expression takes CURIEs instead of labels.  Default `False`
                 :param direct: Return direct subclasses only.  Default `False`
-                :param return_short_forms: Optional.  If `True`, returns short_forms instead of IRIs.
+                :param return_short_forms: Optional.  If `True`, returns short_forms instead of IRIs. Default `True`
                 :return: Returns a list of terms as nested python data structures following VFB_json or a summary_report_json
                 :rtype: list of IRIs or short_forms (depending on return_short_form option)
                 """
         out = self.query(query_type='subclasses', return_type='superClassOf',
                           query=query, query_by_label=query_by_label,
-                          direct=direct)
+                          direct=direct, verbose=verbose)
+        if not isinstance(out,list):
+            print("\033[33mWarning:\033[0m No results! This is likely due to a query error")
+            print("Query: " + query)
+            print("Results: " + str(self.query(query_type='subclasses', return_type='superClassOf',
+                          query=query, query_by_label=query_by_label,
+                          direct=direct, verbose=True)))
+            return []
         if return_short_forms:
             return list(map(gen_short_form, out))
         else:
             return out
 
-    def get_instances(self, query, query_by_label=False, direct=False, return_short_forms=False):
+    def get_instances(self, query, query_by_label=True, direct=False, return_short_forms=True, verbose=False):
         """Generate list of IDs of all instances of class_expression.
 
                 :param class_expression: A valid OWL class expression, e.g. the name of a class.
                 :param query_by_label: Optional.  If `False``, class_expression takes CURIEs instead of labels.  Default `False`
                 :param direct: Return direct instances only.  Default `False`
-                :param return_short_forms: Optional.  If `True`, returns short_forms instead of IRIs.
+                :param return_short_forms: Optional.  If `True`, returns short_forms instead of IRIs. Default `True`
                 :return: Returns a list of terms as nested python data structures following VFB_json or a summary_report_json
                 :rtype: list of IRIs or short_forms (depending on return_short_form option)
                 """
         out = self.query(query_type='instances', return_type='hasInstance',
                           query=query, query_by_label=query_by_label,
-                          direct=direct)
+                          direct=direct, verbose=verbose)
+        if not isinstance(out,list):
+            print("\033[33mWarning:\033[0m No results! This is likely due to a query error")
+            print("Query: " + query)
+            print("Results: " + str(self.query(query_type='subclasses', return_type='superClassOf',
+                          query=query, query_by_label=query_by_label,
+                          direct=direct, verbose=True)))
+            return []
         if return_short_forms:
             return list(map(gen_short_form, out))
         else:
             return out
 
-    def get_superclasses(self, query, query_by_label=False, direct=False, return_short_forms=False):
+    def get_superclasses(self, query, query_by_label=True, direct=False, return_short_forms=True, verbose=False):
         """Generate list of IDs of all superclasses of class_expression.
 
-                       :param class_expression: A valid OWL class expression, e.g. the name (or CURIE) of a class.
-                       :param query_by_label: Optional.  If `False``, class_expression takes CURIEs instead of labels.  Default `False`
-                       :param direct: Return direct instances only.  Default `False`
-                       :param return_short_forms: Optional.  If `True`, returns short_forms instead of IRIs.
-                       :return: Returns a list of terms as nested python data structures following VFB_json or a summary_report_json
-                       :rtype: list of IRIs or short_forms (depending on return_short_form option)
-                       """
+        :param class_expression: A valid OWL class expression, e.g. the name (or CURIE) of a class.
+        :param query_by_label: Optional.  If `False``, class_expression takes CURIEs instead of labels.  Default `False`
+        :param direct: Return direct instances only.  Default `False`
+        :param return_short_forms: Optional.  If `True`, returns short_forms instead of IRIs. Default `True`
+        :return: Returns a list of terms as nested python data structures following VFB_json or a summary_report_json
+        :rtype: list of IRIs or short_forms (depending on return_short_form option)
+        """
         out = self.query(query_type='superclasses', return_type='subClassOf',
                           query=query, query_by_label=query_by_label,
-                          direct=direct)
+                          direct=direct, verbose=verbose)
+        if not isinstance(out,list):
+            print("\033[33mWarning:\033[0m No results! This is likely due to a query error")
+            print("Query: " + query)
+            print("Results: " + str(self.query(query_type='subclasses', return_type='superClassOf',
+                          query=query, query_by_label=query_by_label,
+                          direct=direct, verbose=True)))
+            return []
         if return_short_forms:
             return list(map(gen_short_form, out))
         else:
@@ -138,15 +162,15 @@ class OWLeryConnect:
 
 
     def labels_2_ids(self, query_string):
-        """Substitutes labels for IDs in a query string
+        """Substitutes labels for CURIEs in a query string
 
         :param query_string: A OWL class expression in which all labels of OWL entities are single-quoted.  Internal
         single quotes should be escaped with a backslash.
-        :return: query string in which labels have been converted to unquoted CURIES.
+        :return: query string in which labels have been converted to unquoted CURIEs.
         """
-
+        from vfb_connect import vfb
         def subgp1_or_fail(m):
-            out = self.lookup.get(m.group(1))
+            out = vfb.lookup_id(m.group(1), return_curie=True)
             if not out:
                 raise ValueError("Query includes unknown term label: " + query_string)
             else:
